@@ -64,16 +64,19 @@ gboolean DOING_GDM_DEVELOPMENT = FALSE;
 GtkWidget *window;
 GtkWidget *canvas;
 
-gboolean GDM_IS_LOCAL = FALSE;
-
-gint greeter_current_delay = 0;
+gboolean GDM_IS_LOCAL          = FALSE;
 static gboolean ignore_buttons = FALSE;
+gboolean GdmHaltFound          = FALSE;
+gboolean GdmRebootFound        = FALSE;
+gboolean GdmSuspendFound       = FALSE;
+gboolean GdmConfiguratorFound  = FALSE;
 
 /* FIXME: hack */
 GreeterItemInfo *welcome_string_info = NULL;
 
 extern gboolean session_dir_whacked_out;
 extern gboolean require_quarter;
+extern gint gdm_timed_delay;
 
 gboolean greeter_probably_login_prompt = FALSE;
 
@@ -182,8 +185,11 @@ greeter_ctrl_handler (GIOChannel *source,
     case GDM_NOECHO:
         g_io_channel_read_chars (source, buf, PIPE_SIZE-1, &len, NULL);
 	buf[len-1] = '\0';
-
 	tmp = ve_locale_to_utf8 (buf);
+
+	if (tmp != NULL && strcmp (tmp, _("Password:")) == 0)
+		greeter_probably_login_prompt = FALSE;
+
 	greeter_ignore_buttons (FALSE);
 	greeter_item_pam_prompt (tmp, PW_ENTRY_SIZE, FALSE);
 	g_free (tmp);
@@ -568,8 +574,8 @@ verify_gdm_version (void)
     
       msg =  g_strdup_printf (_("The greeter version (%s) does not match the daemon "
                                 "version.  "
-                                "You have probably just upgraded gdm.  "
-                                "Please restart the gdm daemon or the computer."),
+                                "You have probably just upgraded GDM.  "
+                                "Please restart the GDM daemon or the computer."),
                               VERSION);
     
       dialog = ve_hig_dialog_new (NULL /* parent */,
@@ -603,8 +609,8 @@ verify_gdm_version (void)
     
       msg = g_strdup_printf (_("The greeter version (%s) does not match the daemon "
                                "version. "
-                               "You have probably just upgraded gdm. "
-                               "Please restart the gdm daemon or the computer."),
+                               "You have probably just upgraded GDM. "
+                               "Please restart the GDM daemon or the computer."),
                              VERSION);
     
       dialog = ve_hig_dialog_new (NULL /* parent */,
@@ -616,7 +622,7 @@ verify_gdm_version (void)
       g_free (msg);
 			  
       gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-			      _("Reboot"),
+			      _("Restart Machine"),
 			      RESPONSE_REBOOT,
 			      GTK_STOCK_CLOSE,
 			      RESPONSE_CLOSE,
@@ -652,8 +658,8 @@ verify_gdm_version (void)
     
       msg = g_strdup_printf (_("The greeter version (%s) does not match the daemon "
                                "version (%s).  "
-                               "You have probably just upgraded gdm.  "
-                               "Please restart the gdm daemon or the computer."),
+                               "You have probably just upgraded GDM.  "
+                               "Please restart the GDM daemon or the computer."),
                              VERSION, gdm_version);
     
       dialog = ve_hig_dialog_new (NULL /* parent */,
@@ -665,9 +671,9 @@ verify_gdm_version (void)
       g_free (msg);
 
       gtk_dialog_add_buttons (GTK_DIALOG (dialog),
-			      _("Restart"),
+			      _("Restart GDM"),
 			      RESPONSE_RESTART,
-			      _("Reboot"),
+			      _("Restart Machine"),
 			      RESPONSE_REBOOT,
 			      GTK_STOCK_CLOSE,
 			      RESPONSE_CLOSE,
@@ -701,7 +707,7 @@ verify_gdm_version (void)
 static void
 gdm_set_welcomemsg (void)
 {
-	char *welcomemsg = gdm_get_welcomemsg ();
+	char *welcomemsg = gdm_common_get_welcomemsg ();
 
 	if (welcome_string_info->data.text.orig_text != NULL)
 		g_free (welcome_string_info->data.text.orig_text);
@@ -721,27 +727,28 @@ greeter_reread_config (int sig, gpointer data)
 	    gdm_config_reload_string (GDM_KEY_GRAPHICAL_THEME_DIR) ||
 	    gdm_config_reload_string (GDM_KEY_GTKRC) ||
 	    gdm_config_reload_string (GDM_KEY_GTK_THEME) ||
-	    gdm_config_reload_int    (GDM_KEY_XINERAMA_SCREEN) ||
-	    gdm_config_reload_bool   (GDM_KEY_ENTRY_CIRCLES) ||
-	    gdm_config_reload_bool   (GDM_KEY_ENTRY_INVISIBLE) ||
-	    gdm_config_reload_bool   (GDM_KEY_SHOW_XTERM_FAILSAFE) ||
-	    gdm_config_reload_bool   (GDM_KEY_SHOW_GNOME_FAILSAFE) ||
-	    gdm_config_reload_bool   (GDM_KEY_INCLUDE_ALL) ||
 	    gdm_config_reload_string (GDM_KEY_INCLUDE) ||
 	    gdm_config_reload_string (GDM_KEY_EXCLUDE) ||
 	    gdm_config_reload_string (GDM_KEY_SESSION_DESKTOP_DIR) ||
 	    gdm_config_reload_string (GDM_KEY_LOCALE_FILE) ||
-	    gdm_config_reload_bool   (GDM_KEY_SYSTEM_MENU) ||
 	    gdm_config_reload_string (GDM_KEY_HALT) ||
 	    gdm_config_reload_string (GDM_KEY_REBOOT) ||
 	    gdm_config_reload_string (GDM_KEY_SUSPEND) ||
 	    gdm_config_reload_string (GDM_KEY_CONFIGURATOR) ||
 	    gdm_config_reload_string (GDM_KEY_INFO_MSG_FILE) ||
 	    gdm_config_reload_string (GDM_KEY_INFO_MSG_FONT) ||
+	    gdm_config_reload_string (GDM_KEY_TIMED_LOGIN) ||
+	    gdm_config_reload_int    (GDM_KEY_XINERAMA_SCREEN) ||
+	    gdm_config_reload_int    (GDM_KEY_TIMED_LOGIN_DELAY) ||
+	    gdm_config_reload_bool   (GDM_KEY_ENTRY_CIRCLES) ||
+	    gdm_config_reload_bool   (GDM_KEY_ENTRY_INVISIBLE) ||
+	    gdm_config_reload_bool   (GDM_KEY_SHOW_XTERM_FAILSAFE) ||
+	    gdm_config_reload_bool   (GDM_KEY_SHOW_GNOME_FAILSAFE) ||
+	    gdm_config_reload_bool   (GDM_KEY_INCLUDE_ALL) ||
+	    gdm_config_reload_bool   (GDM_KEY_SYSTEM_MENU) ||
 	    gdm_config_reload_bool   (GDM_KEY_CONFIG_AVAILABLE) ||
 	    gdm_config_reload_bool   (GDM_KEY_CHOOSER_BUTTON) ||
-	    gdm_config_reload_bool   (GDM_KEY_TIMED_LOGIN_ENABLE) ||
-	    gdm_config_reload_int    (GDM_KEY_TIMED_LOGIN_DELAY)) {
+	    gdm_config_reload_bool   (GDM_KEY_TIMED_LOGIN_ENABLE)) {
 
 		/* Set busy cursor */
 		gdm_common_setup_cursor (GDK_WATCH);
@@ -804,14 +811,14 @@ get_theme_file (const char *in, char **theme_dir)
       dir = NULL;
       if (DOING_GDM_DEVELOPMENT)
         {
-	  if (access (in, F_OK) == 0)
+	  if (g_access (in, F_OK) == 0)
 	    {
 	      dir = g_strdup (in);
 	    }
 	  else
 	    {
               dir = g_build_filename ("themes", in, NULL);
-	      if (access (dir, F_OK) != 0)
+	      if (g_access (dir, F_OK) != 0)
 	        {
 	          g_free (dir);
 	          dir = NULL;
@@ -825,11 +832,11 @@ get_theme_file (const char *in, char **theme_dir)
   *theme_dir = dir;
 
   info = g_build_filename (dir, "GdmGreeterTheme.desktop", NULL);
-  if (access (info, F_OK) != 0) {
+  if (g_access (info, F_OK) != 0) {
 	  g_free (info);
 	  info = g_build_filename (dir, "GdmGreeterTheme.info", NULL);
   }
-  if (access (info, F_OK) != 0)
+  if (g_access (info, F_OK) != 0)
     {
       char *base = g_path_get_basename (in);
       /* just guess the name, we have no info about the theme at
@@ -977,12 +984,12 @@ main (int argc, char *argv[])
   /* Load the background as early as possible so GDM does not leave  */
   /* the background unfilled.   The cursor should be a watch already */
   /* but just in case */
-  bg_color = gdm_config_get_string (GDM_KEY_GRAPHICAL_THEME_COLOR);
+  bg_color = gdm_config_get_string (GDM_KEY_GRAPHICAL_THEMED_COLOR);
   /* If a graphical theme color does not exist fallback to the plain color */
   if (ve_string_empty (bg_color)) {
     bg_color = gdm_config_get_string (GDM_KEY_BACKGROUND_COLOR);
   }
-  setup_background_color (bg_color);
+  gdm_common_setup_background_color (bg_color);
   greeter_session_init ();
 
   ve_signal_add (SIGHUP, greeter_reread_config, NULL);
@@ -1034,9 +1041,10 @@ main (int argc, char *argv[])
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
-  if G_UNLIKELY (DOING_GDM_DEVELOPMENT)
-    g_signal_connect (G_OBJECT (window), "key_press_event",
-		      G_CALLBACK (key_press_event), NULL);
+  if G_UNLIKELY (DOING_GDM_DEVELOPMENT) {
+     g_signal_connect (G_OBJECT (window), "key_press_event",
+		       G_CALLBACK (key_press_event), NULL);
+  }
   
   canvas = gnome_canvas_new_aa ();
   GTK_WIDGET_UNSET_FLAGS (canvas, GTK_CAN_FOCUS);
@@ -1050,6 +1058,18 @@ main (int argc, char *argv[])
 			       gdm_wm_screen.height);
   gtk_container_add (GTK_CONTAINER (window), canvas);
 
+ /*
+  * Initialize the value with the default value so the first time it
+  * is displayed it doesn't show as 0.  Also determine if the Halt,
+  * Reboot, Suspend and Configurator commands work.
+  */
+  gdm_timed_delay      = gdm_config_get_int (GDM_KEY_TIMED_LOGIN_DELAY);
+  GdmHaltFound         = gdm_working_command_exists (gdm_config_get_string (GDM_KEY_HALT));
+  GdmRebootFound       = gdm_working_command_exists (gdm_config_get_string (GDM_KEY_REBOOT));
+  GdmSuspendFound      = gdm_working_command_exists (gdm_config_get_string (GDM_KEY_SUSPEND));
+  GdmConfiguratorFound = gdm_working_command_exists (gdm_config_get_string (GDM_KEY_CONFIGURATOR));
+
+
   if (g_getenv ("GDM_THEME") != NULL)
      gdm_graphical_theme = g_strdup (g_getenv ("GDM_THEME"));
   else if (gdm_config_get_bool (GDM_KEY_GRAPHICAL_THEME_RAND))
@@ -1187,7 +1207,7 @@ main (int argc, char *argv[])
 				  _("The GTK+ greeter could not be started.  "
 				    "This display will abort and you may "
 				    "have to login another way and fix the "
-				    "installation of gdm"),
+				    "installation of GDM"),
 				  "");
     
       gtk_widget_show_all (dialog);
@@ -1321,6 +1341,7 @@ main (int argc, char *argv[])
      gdm_config_get_string (GDM_KEY_INFO_MSG_FONT));
 
   gdm_common_setup_cursor (GDK_LEFT_PTR);
+  gdm_common_pre_fetch_launch ();
   gtk_main ();
 
   return 0;
