@@ -18,16 +18,16 @@
 
 #include "config.h"
 
+#include <unistd.h>
+#include <syslog.h>
+
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
+
 #include "greeter.h"
 #include "greeter_configuration.h"
 #include "greeter_system.h"
 #include "greeter_item.h"
-
-#include <syslog.h>
-#include <unistd.h>
-
 #include "gdm.h"
 #include "gdmcommon.h"
 #include "gdmconfig.h"
@@ -35,6 +35,10 @@
 #include "misc.h"
 
 GtkWidget *dialog;
+extern gboolean GdmHaltFound;
+extern gboolean GdmRebootFound;
+extern gboolean GdmSuspendFound;
+extern gboolean GdmConfiguratorFound;
 
 /* doesn't check for executability, just for existance */
 static gboolean
@@ -48,7 +52,7 @@ bin_exists (const char *command)
 	/* Note, check only for existance, not for executability */
 	bin = ve_first_word (command);
 	if (bin != NULL &&
-	    access (bin, F_OK) == 0) {
+	    g_access (bin, F_OK) == 0) {
 		g_free (bin);
 		return TRUE;
 	} else {
@@ -61,7 +65,7 @@ static void
 query_greeter_restart_handler (void)
 {
 	if (gdm_common_warn (_("Are you sure you want to restart the computer?"), "",
-			     _("_Reboot"), NULL, TRUE) == GTK_RESPONSE_YES) {
+			     _("_Restart"), NULL, TRUE) == GTK_RESPONSE_YES) {
 		closelog ();
 		
 		_exit (DISPLAY_REBOOT);
@@ -72,7 +76,7 @@ query_greeter_restart_handler (void)
 static void
 query_greeter_halt_handler (void)
 {
-	if (gdm_common_warn (_("Are you sure you want to shut down the computer?"), "",
+	if (gdm_common_warn (_("Are you sure you want to Shut Down the computer?"), "",
 			     _("Shut _Down"), NULL, TRUE) == GTK_RESPONSE_YES) {
 		closelog ();
 
@@ -136,7 +140,6 @@ greeter_system_append_system_menu (GtkWidget *menu)
 {
 	GtkWidget *w, *sep;
 	static GtkTooltips *tooltips = NULL;
-	gboolean reboot_cmd, halt_cmd, suspend_cmd;
 
 	/* should never be allowed by the UI */
 	if ( ! gdm_config_get_bool (GDM_KEY_SYSTEM_MENU) ||
@@ -147,7 +150,7 @@ greeter_system_append_system_menu (GtkWidget *menu)
 		tooltips = gtk_tooltips_new ();
 
 	if (gdm_config_get_bool (GDM_KEY_CHOOSER_BUTTON)) {
-		w = gtk_menu_item_new_with_mnemonic (_("_XDMCP Chooser..."));
+		w = gtk_menu_item_new_with_mnemonic (_("Remote Login via _XDMCP..."));
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), w);
 		gtk_widget_show (GTK_WIDGET (w));
 		g_signal_connect (G_OBJECT (w), "activate",
@@ -162,7 +165,7 @@ greeter_system_append_system_menu (GtkWidget *menu)
 
 	if (gdm_config_get_bool (GDM_KEY_CONFIG_AVAILABLE) &&
 	    bin_exists (gdm_config_get_string (GDM_KEY_CONFIGURATOR))) {
-		w = gtk_menu_item_new_with_mnemonic (_("_Configure Login Manager..."));
+		w = gtk_menu_item_new_with_mnemonic (_("Confi_gure Login Manager..."));
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), w);
 		gtk_widget_show (GTK_WIDGET (w));
 		g_signal_connect (G_OBJECT (w), "activate",
@@ -174,32 +177,25 @@ greeter_system_append_system_menu (GtkWidget *menu)
 				      NULL);
 	}
 
-	reboot_cmd  = gdm_working_command_exists
-	   (gdm_config_get_string (GDM_KEY_REBOOT));
-	halt_cmd    = gdm_working_command_exists
-	   (gdm_config_get_string (GDM_KEY_HALT));
-	suspend_cmd = gdm_working_command_exists
-	   (gdm_config_get_string (GDM_KEY_SUSPEND));
-
-	if (reboot_cmd || halt_cmd || suspend_cmd) {
+	if (GdmRebootFound || GdmHaltFound || GdmSuspendFound) {
 		sep = gtk_separator_menu_item_new ();
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), sep);
 		gtk_widget_show (sep);
 	}
 
-	if (reboot_cmd) {
-		w = gtk_menu_item_new_with_mnemonic (_("_Reboot"));
+	if (GdmRebootFound) {
+		w = gtk_menu_item_new_with_mnemonic (_("_Restart"));
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), w);
 		gtk_widget_show (GTK_WIDGET (w));
 		g_signal_connect (G_OBJECT (w), "activate",
 				  G_CALLBACK (query_greeter_restart_handler),
 				  NULL);
 		gtk_tooltips_set_tip (tooltips, GTK_WIDGET (w),
-				      _("Reboot your computer"),
+				      _("Restart your computer"),
 				      NULL);
 	}
 
-	if (halt_cmd) {
+	if (GdmHaltFound) {
 		w = gtk_menu_item_new_with_mnemonic (_("Shut _Down"));
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), w);
 		gtk_widget_show (GTK_WIDGET (w));
@@ -207,12 +203,12 @@ greeter_system_append_system_menu (GtkWidget *menu)
 				  G_CALLBACK (query_greeter_halt_handler),
 				  NULL);
 		gtk_tooltips_set_tip (tooltips, GTK_WIDGET (w),
-				      _("Shut down the system so that "
+				      _("Shut Down the system so that "
 					"you may safely turn off the computer."),
 				      NULL);
 	}
 
-	if (suspend_cmd) {
+	if (GdmSuspendFound) {
 		w = gtk_menu_item_new_with_mnemonic (_("Sus_pend"));
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), w);
 		gtk_widget_show (GTK_WIDGET (w));
@@ -251,7 +247,6 @@ greeter_system_handler (GreeterItemInfo *info,
   GtkWidget *restart_radio = NULL;
   GtkWidget *config_radio = NULL;
   GtkWidget *chooser_radio = NULL;
-  gboolean reboot_cmd, halt_cmd, suspend_cmd;
   gchar *s;
   int ret;
   GSList *radio_group = NULL;
@@ -299,21 +294,14 @@ greeter_system_handler (GreeterItemInfo *info,
 		      vbox,
 		      TRUE, TRUE, 0);
 
-  reboot_cmd  = gdm_working_command_exists
-     (gdm_config_get_string (GDM_KEY_REBOOT));
-  halt_cmd    = gdm_working_command_exists
-     (gdm_config_get_string (GDM_KEY_HALT));
-  suspend_cmd = gdm_working_command_exists
-     (gdm_config_get_string (GDM_KEY_SUSPEND));
-
-  if (halt_cmd) {
+  if (GdmHaltFound) {
 	  if (group_radio != NULL)
 		  radio_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (group_radio));
 	  halt_radio = gtk_radio_button_new_with_mnemonic (radio_group,
 							   _("Shut _down the computer"));
 	  group_radio = halt_radio;
 	  gtk_tooltips_set_tip (tooltips, GTK_WIDGET (halt_radio),
-				_("Shut down your computer so that "
+				_("Shut Down your computer so that "
 				  "you may turn it off."),
 				NULL);
 	  g_signal_connect (G_OBJECT(halt_radio), "button_press_event",
@@ -324,14 +312,14 @@ greeter_system_handler (GreeterItemInfo *info,
 	  gtk_widget_show (halt_radio);
   }
 
-  if (reboot_cmd) {
+  if (GdmRebootFound) {
 	  if (group_radio != NULL)
 		  radio_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (group_radio));
 	  restart_radio = gtk_radio_button_new_with_mnemonic (radio_group,
-							     _("_Reboot the computer"));
+							     _("_Restart the computer"));
 	  group_radio = restart_radio;
 	  gtk_tooltips_set_tip (tooltips, GTK_WIDGET (restart_radio),
-				_("Reboot your computer"),
+				_("Restart your computer"),
 				NULL);
 	  g_signal_connect (G_OBJECT(restart_radio), "button_press_event",
 			    G_CALLBACK(radio_button_press_event), NULL);
@@ -341,7 +329,7 @@ greeter_system_handler (GreeterItemInfo *info,
 	  gtk_widget_show (restart_radio);
   }
 
-  if (suspend_cmd) {
+  if (GdmSuspendFound) {
 	  if (group_radio != NULL)
 		  radio_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (group_radio));
 	  suspend_radio = gtk_radio_button_new_with_mnemonic (radio_group,
