@@ -17,8 +17,8 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-#include <config.h>
-#include <glib.h>
+#include "config.h"
+
 #include <string.h>
 #include <unistd.h>
 #include <stdlib.h>
@@ -26,10 +26,11 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <time.h>
-#include <libgnome/libgnome.h>
 
+#include <glib.h>
+
+#include "ve-i18n.h"
 #include "ve-misc.h"
-
 #include "ve-config.h"
 
 typedef struct _VeSection VeSection;
@@ -268,7 +269,7 @@ static time_t
 get_mtime (const char *file)
 {
 	struct stat s;
-	if (stat (file, &s) == 0)
+	if (g_stat (file, &s) == 0)
 		return s.st_mtime;
 	else
 		return 0;
@@ -280,18 +281,26 @@ read_config (VeConfig *config)
 	FILE *fp;
 	VeSection *section = config->root;
 	char buf[2048];
+	int cnt;
+	char *getsret;
 
 	config->mtime = get_mtime (config->file);
 
-	fp = fopen (config->file, "r");
+	VE_IGNORE_EINTR (fp = fopen (config->file, "r"));
 	if (fp == NULL)
 		return;
 
-	while (fgets (buf, sizeof (buf), fp) != NULL) {
+	cnt = 0;
+
+	for (;;) {
 		char *nows = buf;
 		char *eq;
 		char *p;
 
+		VE_IGNORE_EINTR (getsret = fgets (buf, sizeof (buf), fp));
+		if (getsret == NULL)
+			break;
+
 		p = strchr (buf, '\n');
 		if (p != NULL)
 			*p = '\0';
@@ -325,9 +334,16 @@ read_config (VeConfig *config)
 			g_free (val);
 		}
 		/* Note: all invalid lines are whacked from the file */
+
+		/* Note this is a hard limit to avoid run away files.
+		   Do we really expect files longer then 5000 lines?
+		   This is to be ultra anal for security's sake. */
+		cnt ++;
+		if (cnt > 5000)
+			break;
 	}
 
-	fclose (fp);
+	VE_IGNORE_EINTR (fclose (fp));
 }
 
 static VeLine *
@@ -378,6 +394,10 @@ find_or_make_section (VeConfig *config,
 	p = strchr (dkey, '/');
 	if (p == NULL) {
 		*key_name = dkey;
+		/* we're adding to the root which is completely
+		   empty so add a blank line to separate it */
+		if (make_new && config->root->lines == NULL)
+			add_text_line (config, config->root, "");
 		return config->root;
 	}
 	*p = '\0';
@@ -397,7 +417,9 @@ find_or_make_section (VeConfig *config,
 
 	/* Add an empty line on end of last section */
 	last_sect = find_last_section (config);
-	add_text_line (config, last_sect, "");
+	if (last_sect != config->root ||
+	    config->root->lines != NULL)
+		add_text_line (config, last_sect, "");
 
 	section = new_section (config, dkey);
 	config->sections = g_list_append (config->sections, section);
@@ -512,13 +534,13 @@ save_section (VeSection *section, FILE *fp)
 	for (li = section->lines; li != NULL; li = li->next) {
 		VeLine *line = li->data;
 		if (line->type == VE_LINE_TEXT) {
-			fprintf (fp, "%s\n", line->string);
+			VE_IGNORE_EINTR (fprintf (fp, "%s\n", line->string));
 		} else if (line->type == VE_LINE_KEY) {
 			char *out = g_strescape (ve_sure_string (line->string),
 						 G_CSET_LATINC G_CSET_LATINS);
-			fprintf (fp, "%s=%s\n",
-				 line->key,
-				 out);
+			VE_IGNORE_EINTR (fprintf (fp, "%s=%s\n",
+						  line->key,
+						  out));
 			g_free (out);
 		}
 	}
@@ -535,7 +557,7 @@ ve_config_save (VeConfig *config, gboolean force)
 	if ( ! force && ! config->dirty)
 		return TRUE;
 
-	fp = fopen (config->file, "w");
+	VE_IGNORE_EINTR (fp = fopen (config->file, "w"));
 	if (fp == NULL)
 		return FALSE;
 
@@ -543,11 +565,11 @@ ve_config_save (VeConfig *config, gboolean force)
 
 	for (li = config->sections; li != NULL; li = li->next) {
 		VeSection *section = li->data;
-		fprintf (fp, "[%s]\n", section->name);
+		VE_IGNORE_EINTR (fprintf (fp, "[%s]\n", section->name));
 		save_section (section, fp);
 	}
 
-	fclose (fp);
+	VE_IGNORE_EINTR (fclose (fp));
 
 	/* update the mtime */
 	config->mtime = get_mtime (config->file);
